@@ -1,5 +1,5 @@
 /* libaudit.h -- 
- * Copyright 2004-2015 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2004-2017 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -94,6 +94,8 @@ extern "C" {
 #define AUDIT_GRP_MGMT		1132	/* Group account attr was modified */
 #define AUDIT_GRP_CHAUTHTOK	1133	/* Group acct password or pin changed */
 #define AUDIT_MAC_CHECK		1134    /* User space MAC decision results */
+#define AUDIT_ACCT_LOCK		1135    /* User's account locked by admin */
+#define AUDIT_ACCT_UNLOCK	1136    /* User's account unlocked by admin */
 
 #define AUDIT_FIRST_DAEMON	1200
 #define AUDIT_LAST_DAEMON	1299
@@ -102,6 +104,7 @@ extern "C" {
 #define AUDIT_DAEMON_RESUME	1206	/* Auditd should resume logging */
 #define AUDIT_DAEMON_ACCEPT	1207    /* Auditd accepted remote connection */
 #define AUDIT_DAEMON_CLOSE	1208    /* Auditd closed remote connection */
+#define AUDIT_DAEMON_ERR	1209    /* Auditd internal error */
 
 #define AUDIT_FIRST_EVENT	1300
 #define AUDIT_LAST_EVENT	1399
@@ -212,6 +215,11 @@ extern "C" {
 #define AUDIT_VIRT_CONTROL		2500 /* Start, Pause, Stop VM */
 #define AUDIT_VIRT_RESOURCE		2501 /* Resource assignment */
 #define AUDIT_VIRT_MACHINE_ID		2502 /* Binding of label to VM */
+#define AUDIT_VIRT_INTEGRITY_CHECK	2503 /* Guest integrity results */
+#define AUDIT_VIRT_CREATE		2504 /* Creation of guest image */
+#define AUDIT_VIRT_DESTROY		2505 /* Destruction of guest image */
+#define AUDIT_VIRT_MIGRATE_IN		2506 /* Inbound guest migration info */
+#define AUDIT_VIRT_MIGRATE_OUT		2507 /* Outbound guest migration info */
 
 #define AUDIT_LAST_VIRT_MSG		2599
 
@@ -253,6 +261,14 @@ extern "C" {
 #define AUDIT_FEATURE_CHANGE	1328 /* Audit feature changed value */
 #endif
 
+#ifndef AUDIT_REPLACE
+#define AUDIT_REPLACE           1329 /* Auditd replaced because probe failed */
+#endif
+
+#ifndef AUDIT_KERN_MODULE
+#define AUDIT_KERN_MODULE	1330 /* Kernel Module events */
+#endif
+
 #ifndef AUDIT_ANOM_LINK
 #define AUDIT_ANOM_LINK		1702 /* Suspicious use of file links */
 #endif
@@ -265,6 +281,31 @@ extern "C" {
 #define AUDIT_FILTER_MASK	0x07	/* Mask to get actual filter */
 #define AUDIT_FILTER_UNSET	0x80	/* This value means filter is unset */
 
+/* Status symbol mask values */
+#ifndef AUDIT_STATUS_LOST
+#define AUDIT_STATUS_LOST               0x0040
+#endif
+
+/* These defines describe what features are in the kernel */
+#ifndef AUDIT_FEATURE_BITMAP_BACKLOG_LIMIT
+#define AUDIT_FEATURE_BITMAP_BACKLOG_LIMIT      0x00000001
+#endif
+#ifndef AUDIT_FEATURE_BITMAP_BACKLOG_WAIT_TIME
+#define AUDIT_FEATURE_BITMAP_BACKLOG_WAIT_TIME  0x00000002
+#endif
+#ifndef AUDIT_FEATURE_BITMAP_EXECUTABLE_PATH
+#define AUDIT_FEATURE_BITMAP_EXECUTABLE_PATH    0x00000004
+#endif
+#ifndef AUDIT_FEATURE_BITMAP_EXCLUDE_EXTEND
+#define AUDIT_FEATURE_BITMAP_EXCLUDE_EXTEND     0x00000008
+#endif
+#ifndef AUDIT_FEATURE_BITMAP_SESSIONID_FILTER
+#define AUDIT_FEATURE_BITMAP_SESSIONID_FILTER   0x00000010
+#endif
+#ifndef AUDIT_FEATURE_BITMAP_LOST_RESET
+#define AUDIT_FEATURE_BITMAP_LOST_RESET		0x00000020
+#endif
+
 /* Defines for interfield comparison update */
 #ifndef AUDIT_OBJ_UID
 #define AUDIT_OBJ_UID  109
@@ -275,6 +316,13 @@ extern "C" {
 #ifndef AUDIT_FIELD_COMPARE
 #define AUDIT_FIELD_COMPARE 111
 #endif
+#ifndef AUDIT_EXE
+#define AUDIT_EXE 112
+#endif
+
+#ifndef AUDIT_SESSIONID
+#define AUDIT_SESSIONID 25
+#endif
 
 #ifndef AUDIT_COMPARE_UID_TO_OBJ_UID
 #define AUDIT_COMPARE_UID_TO_OBJ_UID   1
@@ -367,6 +415,9 @@ extern "C" {
 #define AUDIT_ARCH_PPC64LE	(EM_PPC64|__AUDIT_ARCH_64BIT|__AUDIT_ARCH_LE)
 #endif
 
+/* This is the character that separates event data from enrichment fields */
+#define AUDIT_INTERP_SEPARATOR 0x1D
+
 //////////////////////////////////////////////////////
 // This is an external ABI. Any changes in here will
 // likely affect pam_loginuid. There might be other
@@ -406,7 +457,7 @@ struct audit_reply {
 	struct nlmsgerr         *error;
 	struct audit_sig_info   *signal_info;
 	struct daemon_conf      *conf;
-#if HAVE_DECL_AUDIT_FEATURE_VERSION
+#ifdef AUDIT_FEATURE_BITMAP_ALL
 	struct audit_features	*features;
 #endif
 	};
@@ -431,7 +482,13 @@ struct audit_dispatcher_header {
 	uint32_t	size;	/* Size of data following the header */
 };
 
-#define AUDISP_PROTOCOL_VER 0
+// Original protocol starts with msg='
+#define AUDISP_PROTOCOL_VER  0
+
+// Starts with node and/or type already in the text before msg=
+// IOW, its preformatted in the audit daemon.
+#define AUDISP_PROTOCOL_VER2 1
+
 
 ///////////////////////////////////////////////////
 // Libaudit API
@@ -472,6 +529,7 @@ extern int  audit_get_reply(int fd, struct audit_reply *rep, reply_t block,
 		int peek);
 extern uid_t audit_getloginuid(void);
 extern int  audit_setloginuid(uid_t uid);
+extern uint32_t audit_get_session(void);
 extern int  audit_detect_machine(void);
 extern int audit_determine_machine(const char *arch);
 
@@ -502,6 +560,7 @@ extern int audit_request_status(int fd);
 extern int audit_is_enabled(int fd);
 extern int get_auditfail_action(auditfail_t *failmode);
 extern int audit_request_features(int fd);
+extern uint32_t audit_get_features(void);
 
 /* AUDIT_SET */
 typedef enum { WAIT_NO, WAIT_YES } rep_wait_t;
@@ -511,6 +570,7 @@ extern int  audit_set_failure(int fd, uint32_t failure);
 extern int  audit_set_rate_limit(int fd, uint32_t limit);
 extern int  audit_set_backlog_limit(int fd, uint32_t limit);
 int audit_set_backlog_wait_time(int fd, uint32_t bwt);
+int audit_reset_lost(int fd);
 extern int  audit_set_feature(int fd, unsigned feature, unsigned value, unsigned lock);
 extern int  audit_set_loginuid_immutable(int fd);
 
@@ -576,9 +636,13 @@ extern int audit_rule_interfield_comp_data(struct audit_rule_data **rulep,
 					 const char *pair, int flags);
 extern void audit_rule_free_data(struct audit_rule_data *rule);
 
+/* Capability testing functions */
+int audit_can_control(void);
+int audit_can_write(void);
+int audit_can_read(void);
+
 #ifdef __cplusplus
 }
 #endif
 
 #endif
-
